# main.py

import pandas as pd
import os
from parameters import net_models, result_folder, log_files
from utils import get_total_sim_time, get_throughput, generate_sim_time_graph, generate_throughput_graph

# Process each model and channel delay setting
for delay, logs in log_files.items():
    sim_time_data = pd.DataFrame(columns=["architecture", "simulation time (us)", "throughput (packets/us)"])
    count = 0

    for arch, models in net_models.items():
        for model in models:
            for log_name, log_type in logs.items():
                log_path = os.path.join(result_folder, log_name)

                # Extract simulation time & throughput
                sim_time = get_total_sim_time(log_path)
                throughput = get_throughput(log_path, sim_time)

                if sim_time is not None and throughput is not None:
                    sim_time_data.loc[count] = [f"{arch} ({log_type})", sim_time, throughput]
                    count += 1
                else:
                    print(f"Warning: No valid simulation time found in {log_path}")

    # Generate graphs separately for each delay setting
    generate_sim_time_graph(sim_time_data, models[0], delay)
    generate_throughput_graph(sim_time_data, models[0], delay)
